@@ -1,19 +1,17 @@
 package ETL::Yertl::Command::ysql;
-$ETL::Yertl::Command::ysql::VERSION = '0.016';
+$ETL::Yertl::Command::ysql::VERSION = '0.017';
 use ETL::Yertl;
 use Getopt::Long qw( GetOptionsFromArray );
 use ETL::Yertl::Format::yaml;
 use File::HomeDir;
 
-BEGIN {
-    eval { use DBI; };
+sub main {
+    my $class = shift;
+
+    eval { require DBI; };
     if ( $@ ) {
         die "Can't load ysql: Can't load DBI. Make sure the DBI module is installed.\n";
     }
-}
-
-sub main {
-    my $class = shift;
 
     my %opt;
     if ( ref $_[-1] eq 'HASH' ) {
@@ -79,9 +77,22 @@ sub main {
     elsif ( $command eq 'config' ) {
         my ( $db_key, @args ) = @_;
 
+        if ( !$db_key ) {
+            my $out_fmt = ETL::Yertl::Format::yaml->new;
+            print $out_fmt->write( config() );
+            return 0;
+        }
+
         # Get the existing config first
         my $db_conf = db_config( $db_key );
 
+        if ( !@args ) {
+            die "Database key '$db_key' does not exist" unless keys %$db_conf;
+            my $out_fmt = ETL::Yertl::Format::yaml->new;
+            print $out_fmt->write( $db_conf );
+            return 0;
+        }
+
         # Set via options
         GetOptionsFromArray( \@args, $db_conf,
             'driver|t=s',
@@ -124,9 +135,21 @@ sub main {
             }
         }
 
+        # Check if the driver is installed
+        my $driver = $db_conf->{driver};
+        if ( !grep { /^$driver$/ } DBI->available_drivers ) {
+            my @possible = grep { /^$driver$/i } DBI->available_drivers;
+            my $suggest = @possible ? " Did you mean: $possible[0]" : '';
+            warn "Driver '$driver' does not exist." . $suggest . "\n";
+        }
+
         # Write back the config
         db_config( $db_key => $db_conf );
     }
+    elsif ( $command eq 'drivers' ) {
+        my $ignore = join "|", qw( ExampleP Sponge File );
+        say join "\n", grep { !/^(?:$ignore)$/ } DBI->available_drivers;
+    }
 }
 
 sub config {
@@ -200,7 +223,7 @@ ETL::Yertl::Command::ysql
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
